@@ -3,7 +3,7 @@ package Devel::Cover::Report::Clover;
 use strict;
 use warnings;
 
-our $VERSION = "0.34_01";
+our $VERSION = "0.10";
 
 use Devel::Cover::Report::Clover::Builder;
 use Getopt::Long;
@@ -12,11 +12,14 @@ use Getopt::Long;
 sub report {
     my ( $pkg, $db, $options ) = @_;
 
-    my $report = builder( $db, $options );
-    my $outfile = output_file($options);
+    my $report = Devel::Cover::Report::Clover::Builder->new( { db => $db } );
+    my $xml_string = $report->generate( output_file($options) );
 
-    printf( "Writing clover output file to '%s'...\n", $outfile ) unless $options->{silent};
-    $report->generate($outfile);
+    printf( "Writing clover output file to '%s'...\n", output_file($options) )
+        unless $options->{silent};
+    open( my $fh, '>', output_file($options) ) or die $!;
+    print {$fh} $xml_string;
+    close($fh);
 
 }
 
@@ -44,17 +47,6 @@ sub output_file {
     return $out_path;
 }
 
-sub builder {
-    my ( $db, $options ) = @_;
-    my $project_name = $options->{option}{projectname};
-    my $report       = Devel::Cover::Report::Clover::Builder->new(
-        {   db                         => $db,
-            name                       => $project_name,
-            include_condition_criteria => 1
-        }
-    );
-}
-
 1;
 
 __END__
@@ -96,31 +88,29 @@ parsed.  This can be any string you want and it defaults to
 
 =back
 
+=item outputfile
+
+Specifies the filename of the main output file.  The default is
+F<coverage.html>.  Specify F<index.html> if you just want to publish the whole
+directory.
+
+
 =head1 SEE ALSO
 
-L<Devel::Cover>
-
-L<http://www.atlassian.com/software/clover/>
-
-L<http://jenkins-ci.org/>
-
-L<https://wiki.jenkins-ci.org/display/JENKINS/Clover+Plugin>
+ L<Devel::Cover>
+ L<http://www.atlassian.com/software/clover/>
 
 =head1 BUGS
 
 L<https://github.com/captin411/Devel-Cover-Report-Clover/issues>
 
-=head1 CREDITS
-
-Jun Kuriyama - nice cosmetic changes to package names
-
 =head1 AUTHOR
 
 David Bartle <captindave@gmail.com>
 
 =head1 LICENSE
 
-Copyright David Bartle (captindave@gmail.com) 
+Copyright 2011, David Bartle (captindave@gmail.com) 
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
